@@ -1,4 +1,4 @@
-/* SPDX-License-Identifier: BSD-2 */
+/* SPDX-License-Identifier: BSD-2-Clause */
 /*
  * Copyright (c) 2017 - 2018, Intel Corporation
  * All rights reserved.
@@ -8,6 +8,7 @@
 #include <inttypes.h>
 
 #include "ipc-frontend-dbus.h"
+#include "tabrmd-defaults.h"
 #include "tabrmd.h"
 #include "util.h"
 
@@ -461,8 +462,8 @@ on_handle_cancel (TctiTabrmd            *skeleton,
                                                "No connection.");
         return TRUE;
     }
-    g_info ("canceling command for connection %p" " with "
-            "id_pid_mix: 0x%" PRIx64, objid (connection), id_pid_mix);
+    g_info ("%s: canceling command for connection with id_pid_mix: 0x%" PRIx64,
+            __func__, id_pid_mix);
     /* cancel any existing commands for the connection */
     g_dbus_method_invocation_return_error (invocation,
                                            TABRMD_ERROR,
@@ -507,16 +508,13 @@ on_handle_set_locality (TctiTabrmd            *skeleton,
     connection = connection_manager_lookup_id (self->connection_manager,
                                                id_pid_mix);
     if (connection == NULL) {
-        g_warning ("no active connection for id_pid_mix: 0x%" PRIx64,
-                   id_pid_mix);
+        g_warning ("%s: no active connection for id", __func__);
         g_dbus_method_invocation_return_error (invocation,
                                                TABRMD_ERROR,
                                                TABRMD_ERROR_NOT_PERMITTED,
                                                "No connection.");
         return TRUE;
     }
-    g_info ("setting locality for connection %p with id_pid_mix: 0x%" PRIx64
-            " to: %" PRIx8, objid (connection), id_pid_mix, locality);
     /* set locality for an existing connection */
     g_dbus_method_invocation_return_error (invocation,
                                            TABRMD_ERROR,
@@ -635,9 +633,17 @@ on_get_dbus_daemon_proxy (GObject      *source_object,
                    "(org.freedesktop.DBus): %s", error->message);
         g_error_free (error);
         self->dbus_daemon_proxy = NULL;
-    } else {
-        g_debug ("Got proxy object for DBus daemon.");
     }
+    g_debug ("Got proxy object for DBus daemon.");
+
+    self->dbus_name_owner_id = g_bus_own_name (self->bus_type,
+                                               self->bus_name,
+                                               G_BUS_NAME_OWNER_FLAGS_NONE,
+                                               on_bus_acquired,
+                                               on_name_acquired,
+                                               on_name_lost,
+                                               self,
+                                               NULL);
 }
 /*
  * This function overrides the ipc_frontend_connect function from the
@@ -656,14 +662,6 @@ ipc_frontend_dbus_connect (IpcFrontendDbus *self,
     g_return_if_fail (IS_IPC_FRONTEND_DBUS (self));
 
     frontend->init_mutex = init_mutex;
-    self->dbus_name_owner_id = g_bus_own_name (self->bus_type,
-                                               self->bus_name,
-                                               G_BUS_NAME_OWNER_FLAGS_NONE,
-                                               on_bus_acquired,
-                                               on_name_acquired,
-                                               on_name_lost,
-                                               self,
-                                               NULL);
     g_dbus_proxy_new_for_bus (self->bus_type,
                               G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
                               NULL,
