@@ -1,4 +1,4 @@
-/* SPDX-License-Identifier: BSD-2 */
+/* SPDX-License-Identifier: BSD-2-Clause */
 /*
  * Copyright (c) 2017 - 2018, Intel Corporation
  * All rights reserved.
@@ -10,6 +10,7 @@
 #include <pthread.h>
 #include <tss2/tss2_tcti.h>
 
+#include "tabrmd-defaults.h"
 #include "tabrmd-generated.h"
 #include "tpm2-header.h"
 #include "util.h"
@@ -110,5 +111,24 @@ const TSS2_TCTI_INFO* Tss2_Tcti_Info (void);
 GBusType tabrmd_bus_type_from_str (const char* const bus_type);
 TSS2_RC tabrmd_kv_callback (const key_value_t *key_value,
                             gpointer user_data);
+TSS2_RC tss2_tcti_tabrmd_transmit (TSS2_TCTI_CONTEXT *context,
+                                   size_t size,
+                                   const uint8_t *command);
+TSS2_RC tss2_tcti_tabrmd_receive (TSS2_TCTI_CONTEXT *context,
+                                  size_t *size,
+                                  uint8_t *response,
+                                  int32_t timeout);
+void tss2_tcti_tabrmd_finalize (TSS2_TCTI_CONTEXT *context);
+TSS2_RC tss2_tcti_tabrmd_cancel (TSS2_TCTI_CONTEXT *context);
+TSS2_RC tss2_tcti_tabrmd_get_poll_handles (TSS2_TCTI_CONTEXT *context,
+                                           TSS2_TCTI_POLL_HANDLE *handles,
+                                           size_t *num_handles);
+TSS2_RC tss2_tcti_tabrmd_set_locality (TSS2_TCTI_CONTEXT *context,
+                                       guint8 locality);
+int tcti_tabrmd_poll (int fd, int32_t timeout);
+TSS2_RC tcti_tabrmd_read (TSS2_TCTI_TABRMD_CONTEXT *ctx,
+                          uint8_t *buf,
+                          size_t size,
+                          int32_t timeout);
 
 #endif /* TSS2TCTI_TABRMD_PRIV_H */
